#ifndef __RSLCX_HEADER
#define __RSLCX_HEADER

#include "rscore.h"
#include "rslcx_attributes.h"
#include "rslcx_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSLCX_CLASS_DRIVER_DESCRIPTION           ""
#define RSLCX_CLASS_DRIVER_PREFIX                ""
#define RSLCX_CLASS_DRIVER_VENDOR                ""
#define RSLCX_CLASS_DRIVER_REVISION              ""
#define RSLCX_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSLCX_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSLCX_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSLCX_SPECIFIC_DRIVER_PREFIX             "RSLCX"
#define RSLCX_SPECIFIC_DRIVER_LOCATOR            ""
#define RSLCX_SPECIFIC_DRIVER_VENDOR             ""
#define RSLCX_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSLCX_MINOR_VERSION                      36L   /* Instrument driver minor version          */
#define RSLCX_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSLCX_SUPPORTED_INSTRUMENT_MODELS        "LCX"    /* Instrument driver supported model(s)     */
#define RSLCX_GROUP_CAPABILITIES                 ""
#define RSLCX_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSLCX_SIMULATION_ID_QUERY      "Rohde&Schwarz,HMC8043,123456/789,1.40"  /* Default definition of ID Query Response for simulation */
#define RSLCX_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSLCX_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSLCX_OPC_TIMEOUT              10000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSLCX_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSLCX_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSLCX_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSLCX_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSLCX_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSLCX_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSLCX_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSLCX_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSLCX_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSLCX_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSLCX_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSLCX_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSLCX_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSLCX_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSLCX_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSLCX_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSLCX_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSLCX_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSLCX_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSLCX_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSLCX_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSLCX_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSLCX_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSLCX_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSLCX_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSLCX_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSLCX_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSLCX_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSLCX_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSLCX_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSLCX_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/
/* BEGIN GENERATE */
#define RSLCX_ATTR_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSLCX_ATTR_VOLTAGE_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSLCX_ATTR_CURRENT_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSLCX_ATTR_AUTORANGE_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSLCX_ATTR_MANUAL_RANGE_VALUE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSLCX_ATTR_LOGGING_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSLCX_ATTR_LOGGING_FILE_NAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSLCX_ATTR_LOGGING_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSLCX_ATTR_LOGGING_INTERVAL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSLCX_ATTR_LOGGING_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSLCX_ATTR_LOGGING_DURATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSLCX_ATTR_LOGGING_START_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSLCX_ATTR_DI_MEASUREMENT_EXECUTE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSLCX_ATTR_DI_MEASUREMENT_SWEEP_PARAMETER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSLCX_ATTR_DI_MEASUREMENT_MINIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSLCX_ATTR_DI_MEASUREMENT_MAXIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSLCX_ATTR_DI_MEASUREMENT_INTERVAL_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSLCX_ATTR_DI_MEASUREMENT_STEP_SIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSLCX_ATTR_DI_MEASUREMENT_NUMBER_OF_POINTS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSLCX_ATTR_DI_MEASUREMENT_ABORT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSLCX_ATTR_BINNING_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSLCX_ATTR_BINNING_LOAD_FROM_FILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSLCX_ATTR_BINNING_SAMPLES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSLCX_ATTR_BINNING_SAMPLES_SINCE_RESET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSLCX_ATTR_BINNING_COUNTER_RESET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSLCX_ATTR_MEASUREMENT_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSLCX_ATTR_MEASUREMENT_SPEED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSLCX_ATTR_MEASUREMENT_CABLE_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSLCX_ATTR_MEASUREMENT_LOW_Z_MODE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSLCX_ATTR_MEASUREMENT_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSLCX_ATTR_MEASUREMENT_IMPEDANCE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSLCX_ATTR_MEASUREMENT_TRIGGER_DELAY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSLCX_ATTR_MEASUREMENT_INIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSLCX_ATTR_BIAS_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSLCX_ATTR_CURRENT_BIAS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSLCX_ATTR_VOLTAGE_BIAS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSLCX_ATTR_BIAS_EXTERNAL_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSLCX_ATTR_BIAS_MEASURE_EXTERNAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_OPEN_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_OPEN_EXECUTE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_OPEN_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_SHORT_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_SHORT_EXECUTE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_SHORT_MODE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_LOAD_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSLCX_ATTR_MEASUREMENT_CORRECTION_LOAD_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSLCX_ATTR_NEXT_VOLTAGE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSLCX_ATTR_NEXT_CURRENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSLCX_ATTR_FRONT_KEY_BRIGHTNESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSLCX_ATTR_USB_CLASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSLCX_ATTR_SYSTEM_VERSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSLCX_ATTR_SYSTEM_HW_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSLCX_ATTR_SYSTEM_RW_LOCK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSLCX_ATTR_SYSTEM_DEVICE_FOOT_PRINT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSLCX_ATTR_SYSTEM_LOCAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSLCX_ATTR_SYSTEM_REMOTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSLCX_ATTR_SYSTEM_RESTART                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSLCX_ATTR_SYSTEM_DATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSLCX_ATTR_SYSTEM_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSLCX_ATTR_SYSTEM_UPTIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSLCX_ATTR_DISPLAY_BRIGHTNESS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSLCX_ATTR_DISPLAY_USER_MESSAGE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSLCX_ATTR_DISPLAY_USER_MESSAGE_CLOSE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSLCX_ATTR_BEEPER_WARNING_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSLCX_ATTR_BEEPER_WARNING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSLCX_ATTR_BEEPER_OPERATION_COMPLETE_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSLCX_ATTR_BEEPER_OPERATION_COMPLETE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSLCX_ATTR_IMAGE_FORMAT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSLCX_ATTR_IMAGE_WIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSLCX_ATTR_IMAGE_HEIGHT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSLCX_ATTR_LAN_DHCP_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSLCX_ATTR_LAN_IP_ADDRESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSLCX_ATTR_LAN_SUBNET_MASK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSLCX_ATTR_LAN_DEFAULT_GATEWAY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSLCX_ATTR_LAN_HOSTNAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSLCX_ATTR_LAN_MAC_ADDRESS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSLCX_ATTR_LAN_PARAMETERS_EDITED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSLCX_ATTR_LAN_APPLY_CHANGES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSLCX_ATTR_LAN_DISCARD_CHANGES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSLCX_ATTR_LAN_RESET_PARAMETERS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSLCX_ATTR_VNC_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSLCX_ATTR_VNC_PORT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSLCX_ATTR_SAVE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSLCX_ATTR_SAVE_TO_FILE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSLCX_ATTR_RECALL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSLCX_ATTR_FILE_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSLCX_ATTR_LIST_OF_FILES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSLCX_ATTR_STATUS_PRESET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSLCX_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSLCX_ATTR_SYSTEM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSLCX_ATTR_SYSTEM_NEXT_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSLCX_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSLCX_ATTR_LOGGING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 156

// RsLcx_rngMeasurementMode
#define RSLCX_VAL_MEASUREMENT_MODE_CONTINUOUS                               0
#define RSLCX_VAL_MEASUREMENT_MODE_TRIGGERED                                1

// RsLcx_rngLoggingMode
#define RSLCX_VAL_LOGGING_MODE_UNLIMITED                                    0
#define RSLCX_VAL_LOGGING_MODE_COUNT                                        1
#define RSLCX_VAL_LOGGING_MODE_DURATION                                     2
#define RSLCX_VAL_LOGGING_MODE_SPAN                                         3

// RsLcx_rngDIMeasureSweepParameter
#define RSLCX_VAL_DI_MEASURE_SWEEP_PARAMETER_VOLTAGE                        0
#define RSLCX_VAL_DI_MEASURE_SWEEP_PARAMETER_FREQUENCY                      1
#define RSLCX_VAL_DI_MEASURE_SWEEP_PARAMETER_VBIAS                          2
#define RSLCX_VAL_DI_MEASURE_SWEEP_PARAMETER_IBIAS                          3

// RsLcx_rngDIMeasurementIntervalType
#define RSLCX_VAL_DI_MEASUREMENT_INTERVAL_TYPE_STEP_SIZE                    0
#define RSLCX_VAL_DI_MEASUREMENT_INTERVAL_TYPE_STEP_NUMBER_OF_POINTS        1

// RsLcx_rngMeasurementSpeed
#define RSLCX_VAL_MEASUREMENT_SPEED_SHORT                                   0
#define RSLCX_VAL_MEASUREMENT_SPEED_MEDIUM                                  1
#define RSLCX_VAL_MEASUREMENT_SPEED_LONG                                    2

// RsLcx_rngMeasurementType
#define RSLCX_VAL_MEASUREMENT_TYPE_L                                        0
#define RSLCX_VAL_MEASUREMENT_TYPE_C                                        1
#define RSLCX_VAL_MEASUREMENT_TYPE_R                                        2
#define RSLCX_VAL_MEASUREMENT_TYPE_T                                        3

// RsLcx_rngMeasurementImpedanceType
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CPD                            0
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CPQ                            1
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CPG                            2
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CPRP                           3
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CSD                            4
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CSQ                            5
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_CSRS                           6
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LPD                            7
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LPQ                            8
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LPG                            9
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LPRP                           10
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LSD                            11
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LSQ                            12
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_LSRS                           13
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_RX                             14
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_RPB                            15
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_RDC                            16
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_MTD                            17
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_NTD                            18
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_ZTD                            19
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_ZTR                            20
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_GB                             21
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_YTD                            22
#define RSLCX_VAL_MEASUREMENT_IMPEDANCE_TYPE_YTR                            23

// RsLcx_rngUSBClass
#define RSLCX_VAL_USB_CLASS_CDC                                             0
#define RSLCX_VAL_USB_CLASS_TMC                                             1

// RsLcx_rngImageFormat
#define RSLCX_VAL_IMAGE_FORMAT_PNG                                          1

// RsLcx_rngStatusRegisterOperation
#define RSLCX_VAL_STAT_REG_QUESTIONABLE                                     1
#define RSLCX_VAL_STAT_REG_OPERATION                                        2

// RsLcx_rngStatusRegisterQuery
#define RSLCX_VAL_STAT_REG_QUERY_COND                                       0
#define RSLCX_VAL_STAT_REG_QUERY_EVENT                                      1
#define RSLCX_VAL_STAT_REG_QUERY_ENABLE                                     2
#define RSLCX_VAL_STAT_REG_QUERY_PTRANSITION                                3
#define RSLCX_VAL_STAT_REG_QUERY_NTRANSITION                                4
/* END GENERATE */

#define RSLCX_VAL_IMPEDANCE_LOW  0
#define RSLCX_VAL_IMPEDANCE_HIGH 1

#define RSLCX_VAL_INTERNAL 0
#define RSLCX_VAL_EXTERNAL 1

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSLCX_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSLCX_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSLCX_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSLCX_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rslcx_init(ViRsrc     resourceName,
                             ViBoolean  IDQuery,
                             ViBoolean  resetDevice,
                             ViSession* instrSession);

ViStatus _VI_FUNC rslcx_InitWithOptions(ViRsrc     resourceName,
                                        ViBoolean  IDQuery,
                                        ViBoolean  resetDevice,
                                        ViString   optionString,
                                        ViSession* instrSession);

ViStatus _VI_FUNC rslcx_ConfigureFrequency(ViSession instrSession,
                                           ViReal64  frequency);

ViStatus _VI_FUNC rslcx_ConfigureVoltageLevel(ViSession instrSession,
                                              ViReal64  voltageLevel);

ViStatus _VI_FUNC rslcx_ConfigureCurrentLevel(ViSession instrSession,
                                              ViReal64  currentLevel);

ViStatus _VI_FUNC rslcx_ConfigureRange(ViSession instrSession,
                                       ViBoolean autorangeEnabled,
                                       ViReal64  manualRangeValue);

ViStatus _VI_FUNC rslcx_ConfigureLogging(ViSession instrSession,
                                         ViString  fileName,
                                         ViInt32   mode);

ViStatus _VI_FUNC rslcx_ConfigureLoggingInterval(ViSession instrSession,
                                                 ViReal64  interval);

ViStatus _VI_FUNC rslcx_ConfigureLoggingCount(ViSession instrSession,
                                              ViInt32   count);

ViStatus _VI_FUNC rslcx_ConfigureLoggingDuration(ViSession instrSession,
                                                 ViReal64  duration);

ViStatus _VI_FUNC rslcx_ConfigureLoggingStartTime(ViSession instrSession,
                                                  ViInt32   year,
                                                  ViInt32   month,
                                                  ViInt32   day,
                                                  ViInt32   hour,
                                                  ViInt32   minute,
                                                  ViInt32   second);

ViStatus _VI_FUNC rslcx_ConfigureLoggingEnabled(ViSession instrSession,
                                                ViBoolean enabled);

ViStatus _VI_FUNC rslcx_ConfigureDIMeasurementSweep(ViSession instrSession,
                                                    ViInt32   sweepParameter,
                                                    ViReal64  minimum,
                                                    ViReal64  maximum);

ViStatus _VI_FUNC rslcx_ConfigureDIMeasurementIntervalType(ViSession instrSession,
                                                           ViInt32   intervalType);

ViStatus _VI_FUNC rslcx_ConfigureDIMeasurementStepSize(ViSession instrSession,
                                                       ViReal64  stepSize);

ViStatus _VI_FUNC rslcx_ConfigureDIMeasurementNumberOfPoints(ViSession instrSession,
                                                             ViInt32   numberOfPoints);

ViStatus _VI_FUNC rslcx_DIMeasurementExecute(ViSession instrSession);

ViStatus _VI_FUNC rslcx_DIMeasurementAbort(ViSession instrSession);

ViStatus _VI_FUNC rslcx_ConfigureBinningEnabled(ViSession instrSession,
                                                ViBoolean binningEnabled);

ViStatus _VI_FUNC rslcx_LoadBinningFromFile(ViSession instrSession,
                                            ViString  filePath);

ViStatus _VI_FUNC rslcx_QueryBinningSamples(ViSession instrSession,
                                            ViInt32*  binningSamples);

ViStatus _VI_FUNC rslcx_QueryBinningSamplesSinceReset(ViSession instrSession,
                                                      ViInt32*  binningSamplesSinceReset);

ViStatus _VI_FUNC rslcx_ResetBinningCounter(ViSession instrSession);

ViStatus _VI_FUNC rslcx_ConfigureMeasurementMode(ViSession instrSession,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rslcx_ConfigureMeasurementType(ViSession instrSession,
                                                 ViInt32   type);

ViStatus _VI_FUNC rslcx_ConfigureMeasurement(ViSession instrSession,
                                             ViInt32   measurementSpeed,
                                             ViInt32   cableLength,
                                             ViInt32   voltageBias,
                                             ViInt32   sourceImpedance,
                                             ViReal64  triggerDelay);

ViStatus _VI_FUNC rslcx_ConfigureMeasurementImpedanceType(ViSession instrSession,
                                                          ViInt32   impedanceType);

ViStatus _VI_FUNC rslcx_MeasurementInit(ViSession instrSession);

ViStatus _VI_FUNC rslcx_ConfigureBiasEnabled(ViSession instrSession,
                                             ViBoolean biasEnabled);

ViStatus _VI_FUNC rslcx_ConfigureCurrentBias(ViSession instrSession,
                                             ViReal64  currentBias);

ViStatus _VI_FUNC rslcx_ConfigureVoltageBias(ViSession instrSession,
                                             ViReal64  voltageBias);

ViStatus _VI_FUNC rslcx_QueryBiasMeasureExternal(ViSession instrSession,
                                                 ViReal64* biasMeasureExternal);

ViStatus _VI_FUNC rslcx_ConfigureMeasurementCorrection(ViSession instrSession,
                                                       ViBoolean openEnabled,
                                                       ViBoolean shortEnabled,
                                                       ViBoolean loadEnabled);

ViStatus _VI_FUNC rslcx_StartMeasurementOpenCorrectionFull(ViSession instrSession);

ViStatus _VI_FUNC rslcx_StartMeasurementShortCorrectionFull(ViSession instrSession);

ViStatus _VI_FUNC rslcx_QueryMeasurementCorrectionOpenMode(ViSession instrSession,
                                                           ViInt32   bufferSize,
                                                           ViChar    result[]);

ViStatus _VI_FUNC rslcx_QueryMeasurementCorrectionShortMode(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    result[]);

ViStatus _VI_FUNC rslcx_QueryMeasurementCorrectionLoadMode(ViSession instrSession,
                                                           ViInt32   bufferSize,
                                                           ViChar    result[]);

ViStatus _VI_FUNC rslcx_StartMeasurementSpotLoadCorrection(ViSession instrSession,
                                                           ViInt32   workingPoint);

ViStatus _VI_FUNC rslcx_StartMeasurementSpotShortCorrection(ViSession instrSession,
                                                            ViInt32   workingPoint);

ViStatus _VI_FUNC rslcx_StartMeasurementSpotOpenCorrection(ViSession instrSession,
                                                           ViInt32   workingPoint);

ViStatus _VI_FUNC rslcx_QueryNextVoltage(ViSession instrSession,
                                         ViReal64* nextVoltage);

ViStatus _VI_FUNC rslcx_QueryNextCurrent(ViSession instrSession,
                                         ViReal64* nextCurrent);

ViStatus _VI_FUNC rslcx_Fetch(ViSession instrSession,
                              ViReal64* z,
                              ViReal64* thetaD);

ViStatus _VI_FUNC rslcx_FetchImpedance(ViSession instrSession,
                                       ViReal64* z,
                                       ViReal64* thetaD);

ViStatus _VI_FUNC rslcx_Read(ViSession instrSession,
                             ViReal64* z,
                             ViReal64* thetaD);

ViStatus _VI_FUNC rslcx_ReadImpedance(ViSession instrSession,
                                      ViReal64* z,
                                      ViReal64* thetaD);

ViStatus _VI_FUNC rslcx_QueryMeasurementAccuracy(ViSession instrSession,
                                                 ViReal64* z,
                                                 ViReal64* thetaD);

ViStatus _VI_FUNC rslcx_ConfigureFrontKeyBrightness(ViSession instrSession,
                                                    ViReal64  brightness);

ViStatus _VI_FUNC rslcx_ConfigureUSBClass(ViSession instrSession,
                                          ViInt32   USBClass);

ViStatus _VI_FUNC rslcx_SystemVersion(ViSession instrSession,
                                      ViInt32   length,
                                      ViChar    systemVersion[]);

ViStatus _VI_FUNC rslcx_SystemDeviceFootPrint(ViSession instrSession,
                                              ViInt32   length,
                                              ViChar    systemDeviceFootPrint[]);

ViStatus _VI_FUNC rslcx_SystemHWVersion(ViSession instrSession,
                                        ViInt32   bufferSize,
                                        ViChar    systemHWVersion[]);

ViStatus _VI_FUNC rslcx_SystemRWLock(ViSession instrSession);

ViStatus _VI_FUNC rslcx_SystemLocal(ViSession instrSession);

ViStatus _VI_FUNC rslcx_SystemRemote(ViSession instrSession);

ViStatus _VI_FUNC rslcx_SystemRestart(ViSession instrSession);

ViStatus _VI_FUNC rslcx_SetSystemDate(ViSession instrSession,
                                      ViInt32   year,
                                      ViInt32   month,
                                      ViInt32   day);

ViStatus _VI_FUNC rslcx_QuerySystemDate(ViSession instrSession,
                                        ViInt32   bufferSize,
                                        ViChar    systemDate[]);

ViStatus _VI_FUNC rslcx_SetSystemTime(ViSession instrSession,
                                      ViInt32   hour,
                                      ViInt32   minute,
                                      ViInt32   second);

ViStatus _VI_FUNC rslcx_QuerySystemTime(ViSession instrSession,
                                        ViInt32   bufferSize,
                                        ViChar    systemTime[]);

ViStatus _VI_FUNC rslcx_QuerySystemUptime(ViSession instrSession,
                                          ViInt32   bufferSize,
                                          ViChar    systemUptime[]);

ViStatus _VI_FUNC rslcx_ConfigureVNC(ViSession instrSession,
                                     ViBoolean enabled,
                                     ViInt32   port);

ViStatus _VI_FUNC rslcx_ConfigureDisplayBrightness(ViSession instrSession,
                                                   ViReal64  brightness);

ViStatus _VI_FUNC rslcx_ConfigureDisplayUserMessage(ViSession instrSession,
                                                    ViString  userMessageText);

ViStatus _VI_FUNC rslcx_DisplayUserMessageClose(ViSession instrSession);

ViStatus _VI_FUNC rslcx_ConfigureBeeper(ViSession instrSession,
                                        ViBoolean warningEnabled,
                                        ViBoolean operationCompleteEnabled);

ViStatus _VI_FUNC rslcx_WarningBeep(ViSession instrSession);

ViStatus _VI_FUNC rslcx_OperationCompleteBeep(ViSession instrSession);

ViStatus _VI_FUNC rslcx_ImageSnapshot(ViSession instrSession,
                                      ViString  destination);

ViStatus _VI_FUNC rslcx_ConfigureImageFormat(ViSession instrSession,
                                             ViInt32   imageFormat);

ViStatus _VI_FUNC rslcx_QueryImageSize(ViSession instrSession,
                                       ViInt32*  imageWidth,
                                       ViInt32*  imageHeight);

ViStatus _VI_FUNC rslcx_ConfigureLANDHCPEnabled(ViSession instrSession,
                                                ViBoolean DHCPEnabled);

ViStatus _VI_FUNC rslcx_ConfigureLANIPAddress(ViSession instrSession,
                                              ViString  IPAddress);

ViStatus _VI_FUNC rslcx_ConfigureLANSubnetMask(ViSession instrSession,
                                               ViString  subnetMask);

ViStatus _VI_FUNC rslcx_ConfigureLANDefaultGateway(ViSession instrSession,
                                                   ViString  defaultGateway);

ViStatus _VI_FUNC rslcx_ConfigureLANHostname(ViSession instrSession,
                                             ViString  hostname);

ViStatus _VI_FUNC rslcx_QueryLANMACAddress(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    MACAddress[]);

ViStatus _VI_FUNC rslcx_QueryLANParametersEdited(ViSession  instrSession,
                                                 ViBoolean* parametersEdited);

ViStatus _VI_FUNC rslcx_LANApplyChanges(ViSession instrSession);

ViStatus _VI_FUNC rslcx_LANDiscardChanges(ViSession instrSession);

ViStatus _VI_FUNC rslcx_LANResetParameters(ViSession instrSession);

ViStatus _VI_FUNC rslcx_SaveInstrumentSettings(ViSession instrSession,
                                               ViInt32   save);

ViStatus _VI_FUNC rslcx_RecallInstrumentSettings(ViSession instrSession,
                                                 ViInt32   recall);

ViStatus _VI_FUNC rslcx_SaveInstrumentSettingsToFile(ViSession instrSession,
                                                     ViString  fileName);

ViStatus _VI_FUNC rslcx_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  sourceInstrumentFile,
                                                 ViString  destinationPCFile);

ViStatus _VI_FUNC rslcx_FileDelete(ViSession instrSession,
                                   ViString  filePath);

ViStatus _VI_FUNC rslcx_QueryListOfFiles(ViSession instrSession,
                                         ViInt32   bufferSize,
                                         ViChar    listOfFiles[]);

ViStatus _VI_FUNC rslcx_QueryNumberOfMeasurementsInFile(ViSession instrSession,
                                                        ViString  filePath,
                                                        ViInt32*  numberOfMeasurements);

ViStatus _VI_FUNC rslcx_SetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeID,
                                            ViInt32   attributeValue);

ViStatus _VI_FUNC rslcx_SetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViReal64  attributeValue);

ViStatus _VI_FUNC rslcx_SetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViString  attributeValue);

ViStatus _VI_FUNC rslcx_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeID,
                                              ViBoolean attributeValue);

ViStatus _VI_FUNC rslcx_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeID,
                                               ViString  repCapNameID,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[]);

ViStatus _VI_FUNC rslcx_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rslcx_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rslcx_GetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeID,
                                            ViInt32*  attributeValue);

ViStatus _VI_FUNC rslcx_GetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViReal64* attributeValue);

ViStatus _VI_FUNC rslcx_GetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeID,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[]);

ViStatus _VI_FUNC rslcx_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   repeatedCapabilityName,
                                              ViAttr     attributeID,
                                              ViBoolean* attributeValue);

ViStatus _VI_FUNC rslcx_reset(ViSession instrSession);

ViStatus _VI_FUNC rslcx_self_test(ViSession instrSession,
                                  ViInt16*  testResult,
                                  ViChar    testMessage[]);

ViStatus _VI_FUNC rslcx_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rslcx_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[]);

ViStatus _VI_FUNC rslcx_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[]);

ViStatus _VI_FUNC rslcx_StatusPreset(ViSession instrSession);

ViStatus _VI_FUNC rslcx_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rslcx_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerGroup,
                                          ViInt32   enable,
                                          ViInt32   PTransition,
                                          ViInt32   NTransition);

ViStatus _VI_FUNC rslcx_GetStatusRegister(ViSession instrSession,
                                          ViInt32   registerGroup,
                                          ViInt32   registerType,
                                          ViInt32*  registerValue);

ViStatus _VI_FUNC rslcx_IDQueryResponse(ViSession instrSession,
                                        ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rslcx_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rslcx_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC);

ViStatus _VI_FUNC rslcx_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking);

ViStatus _VI_FUNC rslcx_SetVISATimeout(ViSession instrSession,
                                       ViUInt32  VISATimeout);

ViStatus _VI_FUNC rslcx_GetVISATimeout(ViSession instrSession,
                                       ViUInt32* VISATimeout);

ViStatus _VI_FUNC rslcx_SetOPCTimeout(ViSession instrSession,
                                      ViInt32   timeout);

ViStatus _VI_FUNC rslcx_GetOPCTimeout(ViSession instrSession,
                                      ViInt32*  timeout);

ViStatus _VI_FUNC rslcx_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rslcx_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rslcx_GetError(ViSession instrSession,
                                 ViStatus* code,
                                 ViInt32   bufferSize,
                                 ViChar    description[]);

ViStatus _VI_FUNC rslcx_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rslcx_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer);

ViStatus _VI_FUNC rslcx_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value);

ViStatus _VI_FUNC rslcx_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value);

ViStatus _VI_FUNC rslcx_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value);

ViStatus _VI_FUNC rslcx_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[]);

ViStatus _VI_FUNC rslcx_close(ViSession instrSession);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSLCX_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSLCX_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSLCX_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSLCX_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSLCX_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSLCX_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSLCX_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSLCX_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSLCX_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSLCX_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSLCX_ERROR_CODES_AND_MSGS \
    {RSLCX_WARN_MEASURE_UNCALIBRATED,  RSLCX_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSLCX_WARN_OVER_RANGE,            RSLCX_WARNMSG_OVER_RANGE},\
    {RSLCX_ERROR_INCORRECT_STATE ,   RSLCX_ERRMSG_INCORRECT_STATE },\
    {RSLCX_ERROR_INCORRECT_RESPONSE,     RSLCX_ERRMSG_INCORRECT_RESPONSE},\
    {RSLCX_ERROR_MAX_TIME_EXCEEDED,    RSLCX_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSLCX_HEADER */
